import { BackgroundImage } from '@rneui/base';
import { FlatList, StyleSheet, Text, View, Image, TouchableOpacity } from 'react-native';
import { SafeAreaView } from 'react-native-safe-area-context';
import MapView, { Circle, Polygon, Polyline } from 'react-native-maps';
import PROVIDER_OPENSTREETMAP, { Marker } from 'react-native-maps';
import React from 'react';
import { Session } from '../core/Session';
import { Lap as LapModel}   from '../core/Lap';

export default function Lap({route}) {
    const { session } = route.params;

    // const laps: LapModel[] = session.getLaps();
    const laps: LapModel[] = session.getLaps().sort((lap1, lap2) => lap1.getNumber() - lap2.getNumber());


    const [currentLapIndex, setCurrentLapIndex] = React.useState(0);
    const currentLap: LapModel | undefined = laps[currentLapIndex];

    const goToPreviousLap = () => {
        if (currentLapIndex > 0) {
            setCurrentLapIndex(currentLapIndex - 1);
        }
    };

    const goToNextLap = () => {
        if (currentLapIndex < laps.length - 1) {
            setCurrentLapIndex(currentLapIndex + 1);
        }
    };

    const points : any = [];
    currentLap.getPoints().forEach(pt => {
        points.push({ latitude: pt.getGeo().getGpsLat(), longitude: pt.getGeo().getGpsLong() });
            
    });

    //var currentLap : undefined; // Penser à vérifier si la session ne possède pas de tour !! si c'est le cas afficher une popup d'erreur
    return (
        <SafeAreaView style={styles.container}>
            <View style={styles.container}>
                {/* Header */}
                <View style={styles.topbar}>
                    <View>
                        <TouchableOpacity style={styles.accountContainerButton}  disabled={currentLapIndex === 0}>
                            <View style={styles.ImageContainer}>
                                <Image source={require('../assets/images/pfp.png')} style={styles.accountImage} />
                            </View>
                            <Text style={styles.accountName}>Mr X</Text>
                        </TouchableOpacity>
                    </View>
                    <View style={styles.topbarRight}>
                        <View style={styles.iconContainer}>
                            <Image source={require('../assets/images/settings.png')} style={styles.accountSettings} />
                        </View>
                        <TouchableOpacity style={styles.accountContainerButton} disabled={currentLapIndex === laps.length - 1}>
                            <View style={styles.ImageContainer}>
                                <Image source={require('../assets/images/rdash.png')} style={styles.accountImage} />
                            </View>
                        </TouchableOpacity>
                    </View>
                </View>
                
                {/* Body */}
                <View style={styles.container}>

                        <View style={styles.top_lap}>
                            <TouchableOpacity style={[styles.LapBrowserButton, currentLapIndex === 0 ? styles.disabled : null]} onPress={goToPreviousLap}>
                                <View>
                                    <Text style={styles.button_text} >Previous lap</Text>
                                </View>
                            </TouchableOpacity>

                            <Text style={styles.text_title}>Lap {currentLap?.getNumber()} </Text>

                            <TouchableOpacity style={[styles.LapBrowserButton, currentLapIndex === laps.length - 1 ? styles.disabled : null]} onPress={goToNextLap}>
                                <View>
                                    <Text style={styles.button_text} >Next lap</Text>
                                </View>
                            </TouchableOpacity>

                        </View>

                        <View style={styles.containerBody}>
                            <MapView
                                style={styles.map}
                                mapType="satellite"
                                region={{
                                    latitude:  currentLap.getLocationLat(),
                                    longitude: currentLap.getLocationLong(),
                                    latitudeDelta: 0.001,
                                    longitudeDelta: 0.015,
                                }}
                            >
                                <Polyline
                                    coordinates={points}
                                    strokeColor="#000" // set the color of the line
                                    strokeWidth={3} // set the width of the line
                                    />
                                {/* <Marker
                                    coordinate={{
                                        latitude: 45.76013484856403,
                                        longitude: 3.112214188782891,
                                    }}
                                    onPress={() => console.log('pressed')}
                                /> */}

                            </MapView>
                            <BackgroundImage source={require('../assets/images/rdash.png')} resizeMode="contain" >   
                                <View style={styles.container2}>

                                <Text style={styles.header}>Lap Information</Text>
                                
                                <View style={styles.infoContainer}>
                                    <Text style={styles.infoItem}>Lap Time:</Text>
                                    <Text style={styles.infoValue}>{currentLap.getFormattedTime()}</Text>
                                </View>

                                <View style={styles.infoContainer}>
                                    <Text style={styles.infoItem}>Average Speed:</Text>
                                    <Text style={styles.infoValue}>{currentLap.getAverageSpeed()} km/h</Text>
                                </View>

                                <View style={styles.infoContainer}>
                                    <Text style={styles.infoItem}>Max Speed:</Text>
                                    <Text style={styles.infoValue}>{} km/h</Text>
                                </View>
                                
                                <View style={styles.infoContainer}>
                                    <Text style={styles.infoItem}>X:</Text>
                                    <Text style={styles.infoValue}>{} X</Text>
                                </View>

                                <View style={styles.infoContainer}>
                                    <Text style={styles.infoItem}>X:</Text>
                                    <Text style={styles.infoValue}>{} X</Text>
                                </View>
                                </View>
                            </BackgroundImage>
                        </View>
                </View>

            </View>
        </SafeAreaView>
    );
}

// TROUBLE SHOOTING BORDER :
//borderColor:'red',
//borderWidth:3,

const styles = StyleSheet.create({
    card: {
        flexDirection: 'column',
        height: "80%",
        width: "80%",
        backgroundColor: "#fff",
        borderRadius: 15,
        padding: 10,
        elevation: 10,
        shadowColor: '#000',
        shadowOffset: { width: 0, height: 3 },
        shadowOpacity: 0.5,
        shadowRadius: 5,
    },
    containerBody:{
        flex: 1,
        justifyContent: 'space-between',
        alignItems: 'stretch',
    },
    container2: {
        backgroundColor: 'rgba(255, 255, 255, 0.9)',
        borderColor:'black',
        borderWidth:2,
        padding: 10,
        borderRadius: 10,
        marginBottom: 20,
        shadowColor: '#000',
        shadowOffset: {
            width: 0,
            height: 2,
            },
        shadowOpacity: 0.25,
        shadowRadius: 3.84,
        elevation: 5,
    },
    header: {
        fontSize: 24,
        fontWeight: 'bold',
        marginBottom: 10,
    },
    infoContainer: {
        flexDirection: 'row',
        justifyContent: 'space-between',
        marginBottom: 5,
    },
    infoItem: {
        fontSize: 18,
        fontWeight: 'bold',
    },
    infoValue: {
        fontSize: 18,
    },
    
    map: {
        flex:1,
    },
    top_lap: {
        height: "8%",
        flexDirection: 'row',
        justifyContent: 'space-between',
        margin:10,
    },
    backgroundImage: {
        flex: 1,
        width: '100%',
    },

    container: {
        flex: 1,
    },

    accountSettings: {
        width: '100%',
        height: '100%',
    },

    accountContainerButton: {
        flexDirection: 'row',
        alignItems: 'center',
    },

    LapBrowserButton: {
        width: "30%",
        margin: 5,
        alignContent: 'center',
        justifyContent: 'center',
        borderRadius: 10,
        backgroundColor: '#BF181F',
    },
    button_text: {
        textAlign: 'center',
        color: '#fff',
        fontSize: 20,
    },

    ImageContainer: {
        backgroundColor: '#fff',
        borderRadius: 50,
        width: 40,
        height: 40,
        overflow: 'hidden',
        marginRight: 10,

    },
    accountImage: {
        width: '100%',
        height: '100%',
    },
    topbar: {
        backgroundColor: '#BF181D',
        flexDirection: 'row',
        alignItems: 'center',
        justifyContent: 'space-between',
        paddingHorizontal: 20,
        height: "8%",
    },
    accountName: {
        color: '#fff',
        fontSize: 20,
    },
    topbarRight: {
        flex: 1,
        alignItems: 'flex-end',
    },
    
    text_title: {
        fontWeight: 'bold',
        fontSize: 30,
        textAlign: 'center',
        textShadowColor: '#fff',
        textShadowOffset: { width: 0, height: 0 },
        textShadowRadius: 10,
    },
    iconContainer: {
        position: 'absolute',
        bottom: 0,
        right: 0,
        backgroundColor: 'transparent',
        width: 24,
        height: 24,
    },
});