import { StatusBar } from 'expo-status-bar';
import React, { useState } from 'react';
import { Button, Pressable, StyleSheet, Text, View, Image, TouchableOpacity, TextInput } from 'react-native';
import { SafeAreaView } from 'react-native-safe-area-context';
import * as DocumentPicker from 'expo-document-picker';

export default function NewTrack(props: { navigation: any }) {
    const { navigation } = props;

    const [pickedDocument, setPickedDocument] = useState<DocumentPicker.DocumentResult | null>(null);

    const handlePickDocument = async () => {
        try {
            const result = await DocumentPicker.getDocumentAsync({ type: 'excel/xls' });
            if (result.type === 'success') {
                setPickedDocument(result);
            }
        } catch (err) {
            console.log(err);
        }
    };

    return (
        <SafeAreaView>
            <View style={styles.container}>
                <View style={styles.topbar}>
                    <View>
                        <TouchableOpacity style={styles.accountContainerButton}>
                            <View style={styles.ImageContainer}>
                            </View>
                            <Text style={styles.accountName}>Name</Text>
                        </TouchableOpacity>
                    </View>
                    <View style={styles.topbarRight}>
                        <View style={styles.iconContainer}>
                            <Image source={require('../assets/images/settings.png')} style={styles.accountSettings} />
                        </View>
                        <TouchableOpacity style={styles.accountContainerButton}>
                            <View style={styles.ImageContainer}>
                                <Image source={require('../assets/images/image.png')} style={styles.accountImage} />
                            </View>
                        </TouchableOpacity>
                    </View>
                </View>

                {/* Page */}
                <View style={{ alignItems: 'center', width: "100%", height: "80%", justifyContent: 'space-around' }}>
                    <View style={styles.page}>
                        <View style={styles.placement}>
                            <Text style={{ paddingTop: 20 }}>Track name: </Text>
                            <TextInput
                                style={styles.textInput}
                                secureTextEntry={true}
                                placeholder="Track name"
                            />
                        </View>

                        <View style={styles.placement}>
                            <Text style={{ paddingTop: 20 }}>Session name: </Text>
                            <TextInput
                                style={styles.textInput}
                                secureTextEntry={true}
                                placeholder="Session name"
                            />
                        </View>

                        <View style={styles.placement}>
                            <Text style={{ paddingTop: 30 }}>Import file: </Text>
                            <Pressable onPress={handlePickDocument}>
                                <Image style={styles.import} source={require('../assets/images/import.png')} />
                                <Text>
                                    Picked document: {pickedDocument ? pickedDocument.name : 'none'}
                                </Text>
                            </Pressable>
                        </View>

                    </View>
                </View>

                <View style={styles.placement}>
                    <Pressable style={styles.button} onPress={() => navigation.goBack()}>
                        <Image
                            style={styles.return}
                            source={require('../assets/images/return.png')}
                        />
                    </Pressable>
                    <Pressable style={styles.button} onPress={() => navigation.goBack()}>
                        <Image
                            style={styles.return}
                            source={require('../assets/images/checked.png')}
                        />
                    </Pressable>
                </View>
            </View>
        </SafeAreaView>
    );
}
const styles = StyleSheet.create({
    backgroundImage: {
    },

    container: {
        flexDirection: 'column',

    },

    accountSettings: {
        width: '100%',
        height: '100%',
    },
    accountContainerButton: {
        flexDirection: 'row',
        alignItems: 'center',
    },
    ImageContainer: {
        backgroundColor: '#fff',
        borderRadius: 50,
        width: 40,
        height: 40,
        overflow: 'hidden',
        marginRight: 10,
    },
    accountImage: {
        width: '100%',
        height: '100%',
    },
    topbar: {
        backgroundColor: '#BF181D',
        flexDirection: 'row',
        alignItems: 'center',
        justifyContent: 'space-between',
        paddingHorizontal: 20,
        height: 80,
    },
    accountName: {
        color: '#fff',
        fontSize: 20,
    },
    topbarRight: {
        flex: 1,
        alignItems: 'flex-end',
    },
    text_title: {
        flex: 1,
        alignItems: 'flex-start',
        fontWeight: 'bold',
        fontSize: 30,
        textAlign: 'center',
        padding: 10,
    },
    iconContainer: {
        position: 'absolute',
        bottom: 0,
        right: 0,
        backgroundColor: 'transparent',
        width: 24,
        height: 24,
    },
    textInput: {
        alignItems: 'center',
        paddingVertical: 12,
        paddingHorizontal: 32,
        elevation: 3,
        backgroundColor: '#fff',
        borderWidth: 1,
        borderColor: '#000',
        width: '90%',
    },
    import: {
        width: 70,
        height: 70,
        paddingLeft: 20,
    },
    placement: {
        justifyContent: 'space-between',
        flexDirection: 'row',
    },
    page: {
        padding: 20,
        justifyContent: 'space-between',
        alignItems: 'center',
        height: "60%",
        width: "80%",
    },
    button: {
        alignItems: 'center',
        justifyContent: 'center',
        paddingVertical: 12,
        paddingHorizontal: 32,
        borderRadius: 10,
        elevation: 3,
        backgroundColor: '#BF181D',
    },
    return: {
        width: 30,
        height: 30,
    }
});